# Contributing

Tskit is a free and open-source project that welcomes contributions from everyone.
The [Developer documentation](https://tskit.dev/tskit/docs/latest/development.html)
will help you get started. 

We have an active slack group where tskit and associated projects are discussed.
If you wish to join email [admin@tskit.dev](mailto:admin@tskit.dev).

We ask all users to follow our [code of conduct](https://github.com/tskit-dev/.github/blob/main/CODE_OF_CONDUCT.md)
when interacting with the project.
